<TS language="fr_CA" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>Au sujet de Gridcoin</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Créer une nouvelle adresse</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copier l'adresse surligné a votre presse-papier</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>Montrer le &amp;QR Code</translation>
    </message>
    <message>
        <source>Sign a message to prove you own a Gridcoin address</source>
        <translation>Signer un message afin de valider l'identité de votre adresse Gridcoin</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Signer le &amp;message</translation>
    </message>
    <message>
        <source>Verify a message to ensure it was signed with a specified Gridcoin address</source>
        <translation>Vérifier un message pour s'assurer qu'il vient d'une adresse Gridcoin spécifique.</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Vérifier un message</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Effacer l'adresse actuellement sélectionnée de la liste</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>Répertoire d'adresses</translation>
    </message>
    <message>
        <source>These are your Gridcoin addresses for receiving payments. You may want to give a different one to each sender so you can keep track of who is paying you.</source>
        <translation>Ce sont vos adresses pour recevoir vos paiements. Vous pouvez utiliser une adresse différente pour chaque réception afin d'identifier facilement le payeur.</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Copier l'&amp;Étiquette</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Modifier</translation>
    </message>
    <message>
        <source>Export Address Book Data</source>
        <translation>Exporter votre répertoire d'adresses</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Erreur lors de l'export</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Impossible d'écrire dans le fichier %1.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Étiquette</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(aucune étiquette)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dialogue de mot de passe</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Entrer Mot de Passe</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nouveau Mot de passe</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Répéter Mot de Passe</translation>
    </message>
    <message>
        <source>Serves to disable the trivial sendmoney when OS account compromised. Provides no real security.</source>
        <translation>Sert à désactiver les transactions sortantes si votre compte de système d'exploitation est compromis. Ne procure pas de réelle sécurité.</translation>
    </message>
    <message>
        <source>For staking only</source>
        <translation>Pour "staking" seulement</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Crypter le portefeuille</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Cette opération nécessite votre mot de passe pour déverrouiller le portefeuille.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Déverrouiller le portefeuille</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Changer la phrase de passe</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Saisir l’ancienne et la nouvelle phrase de passe du portefeuille</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Confirmer le cryptage du portefeuille</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR COINS&lt;/b&gt;!</source>
        <translation>ATTENTION : Si vous cryptez votre portefeuille et perdez votre mot de passe, vous ne pourrez plus accéder à vos Gridcoins</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Êtes-vous sûr de vouloir crypter votre portefeuille ?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Portefeuille crypté</translation>
    </message>
    <message>
        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
        <translation>L'application Gridcoin va désormais se terminer afin de finaliser le processus de cryptage. Merci de noter que le cryptage du portefeuille ne garantit pas de se prémunir du vol via l'utilisation de malware, qui auraient pu infecter votre ordinateur. </translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>IMPORTANT : Toute sauvegarde précédente de votre fichier de portefeuille devrait être remplacée par le nouveau fichier de portefeuille crypté. Pour des raisons de sécurité, les sauvegardes précédentes de votre fichier de portefeuille non crypté deviendront inutilisables dès lors que vous commencerez à utiliser le nouveau portefeuille crypté.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Le cryptage du portefeuille a échoué</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Le cryptage du portefeuille a échoué en raison d'une erreur interne. Votre portefeuille n'a pas été crypté.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Les mots de passe saisies ne correspondent pas.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Le déverrouillage du portefeuille a échoué</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Le mot de passe saisie pour décrypter le portefeuille était incorrecte.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Le mot de passe du portefeuille a été modifiée avec succès.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Attention : la touche Verr. Maj. est activée !</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>A fatal error occurred. Gridcoin can no longer continue safely and will quit.</source>
        <translation>Une erreur fatale a été rencontrée. L'application Gridcoin ne peut plus être s'exécuter de façon correcte et doit se terminer.</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Portefeuille</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Vue d'ensemble</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Afficher une vue d’ensemble du portefeuille</translation>
    </message>
    <message>
        <source>Send coins to a Gridcoin address</source>
        <translation>Envoyer des monnaies vers une adresse Gridcoin</translation>
    </message>
    <message>
        <source>Show the list of addresses for receiving payments</source>
        <translation>Montrer la liste d'adresses de réception des paiements</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Parcourir l'historique des transactions</translation>
    </message>
    <message>
        <source>Edit the list of stored addresses and labels</source>
        <translation>Éditer la liste d'adresses et libellés</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Q&amp;uitter</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Quitter l’application</translation>
    </message>
    <message>
        <source>&amp;About Gridcoin</source>
        <translation>A propos de Gridcoin</translation>
    </message>
    <message>
        <source>Show information about Gridcoin</source>
        <translation>Afficher des informations au sujet du Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Options…</translation>
    </message>
    <message>
        <source>Modify configuration options for Gridcoin</source>
        <translation>Modification des options de configuration de Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Afficher / Cacher</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Crypter le portefeuille...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Changer le mot de passe...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Modifier le mot de passe utilisée pour le cryptage du portefeuille</translation>
    </message>
    <message>
        <source>&amp;Unlock Wallet...</source>
        <translation>&amp;Déverrouiller le portefeuille</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Déverrouiller le portefeuille</translation>
    </message>
    <message>
        <source>&amp;Lock Wallet</source>
        <translation>&amp;Verrouiller le portefeuille</translation>
    </message>
    <message>
        <source>Lock wallet</source>
        <translation>Verrouiller le portefeuille</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Signer le &amp;message...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Vérifier un message...</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Export des données de l'onglet courant vers un fichier</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Fenêtre de débogage</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Ouvrir une console de débogage et de diagnostic</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Réglages</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>Gridcoin client</source>
        <translation>Client Gridcoin</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>À jour</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Rattrapage en cours…</translation>
    </message>
    <message>
        <source>Last received block was generated %1.</source>
        <translation>Le dernier block reçu à été généré %1.</translation>
    </message>
    <message>
        <source>This transaction is over the size limit.  You can still send it for a fee of %1, which goes to the nodes that process your transaction and helps to support the network.  Do you want to pay the fee?</source>
        <translation>Cette transaction dépasse la limite autorisée. Vous pouvez tout de même effectuer cette opération, moyennant %1 de frais, qui seront envoyés aux noeuds qui valideront cette transaction, et dont l'objectif vise à supporter le réseau. Etes-vous d'accord pour payer ces frais ?</translation>
    </message>
    <message>
        <source>Confirm transaction fee</source>
        <translation>Confirmer le Paiement des frais de transaction</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transaction envoyée</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transaction entrante</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>Prise en charge de l'URL</translation>
    </message>
    <message>
        <source>URI can not be parsed! This can be caused by an invalid Gridcoin address or malformed URI parameters.</source>
        <translation>L'adresse du portefeuille Gridcoin n'as pas pu être correctement identifiée, car invalide ou malformée.</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Le portefeuille est &lt;b&gt;crypté&lt;/b&gt; et actuellement &lt;b&gt;verrouillé&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>Sauvegarder le portefeuille</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>Données liées au portefeuille (*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Echec de la sauvegarde</translation>
    </message>
    <message>
        <source>There was an error trying to save the wallet data to the new location.</source>
        <translation>Une erreur a été rencontrée lors de la tentative de sauvegarde du portefeuille vers la nouvelle destination.</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Alerte réseau</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Quantité :</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Octets :</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Montant :</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Frais :</translation>
    </message>
    <message>
        <source>Coin Control</source>
        <translation>Fonctions de contrôle des monnaies</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Sortie faible :</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Après les frais :</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Monnaie :</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Montant</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmée</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Intitulé</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copier l’adresse</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copier l’étiquette</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copier le montant</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copier l'ID de la transaction</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copier la quantité</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copier les frais</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copier le montant après les frais</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copier les octets</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Copier la sortie faible</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copier la monnaie</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>oui</translation>
    </message>
    <message>
        <source>no</source>
        <translation>non</translation>
    </message>
    <message>
        <source>This label turns red, if the transaction size is bigger than 10000 bytes.

 This means a fee of at least %1 per kb is required.

 Can vary +/- 1 Byte per input.</source>
        <translation>Cet intitulé passe au rouge, si la taille de la transaction est supérieure à 10000 bytes.

Cela implique que des frais à hauteur d'au moins %1 par kb seront nécessaires.

Ceux-ci Peuvent varier de +/- 1 Byte par entrée.</translation>
    </message>
    <message>
        <source>This label turns red, if any recipient receives an amount smaller than %1.

 This means a fee of at least %2 is required. 

 Amounts below 0.546 times the minimum relay fee are shown as DUST.</source>
        <translation>Ce label passe au rouge, Lorsqu'un destinataire reçoit un montant inférieur à %1.

 Cela implique que des frais à hauteur de %2 seront nécessaire 

Les montants inférieurs à  0.546 fois les frais minimum de relais apparaissent en tant que DUST.</translation>
    </message>
    <message>
        <source>This label turns red, if the change is smaller than %1.

 This means a fee of at least %2 is required.</source>
        <translation>Ce label passe au rouge, lorsque la différence est inférieure à %1.

 Cela implique que des frais à hauteur d'au moins %2 seront nécessaires.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(aucune étiquette)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>monnaie de %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(monnaie)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Modifier l'adresse</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>Record</translation>
    </message>
    <message>
        <source>The label associated with this address book entry</source>
        <translation>L'intitulé associé à cette entrée du carnet d'adresse</translation>
    </message>
    <message>
        <source>The address associated with this address book entry. This can only be modified for sending addresses.</source>
        <translation>L'intitulé associé à cette entrée du carnet d'adresse. Seules les adresses d'envoi peuvent être modifiées.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>Addresse</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nouvelle adresse de réception</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nouvelle adresse d’envoi</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Modifier l’adresse de réception</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Modifier l’adresse d'envoi</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Gridcoin address.</source>
        <translation>L'adresse "%1" renseignée n'est pas une adresse Gridcoin valide.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>L’adresse fournie « %1 » est déjà présente dans le carnet d'adresses.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Impossible de déverrouiller le portefeuille.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Échec de génération de la nouvelle clef.</translation>
    </message>
</context>
<context>
    <name>GUIUtil::HelpMessageBox</name>
    <message>
        <source>Usage:</source>
        <translation>Utilisation:</translation>
    </message>
    <message>
        <source>command-line options</source>
        <translation>Options de ligne de commande</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>&amp;Main</source>
        <translation>Réglages &amp;principaux</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Réseau</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Mapper le port avec l'&amp;UPnP</translation>
    </message>
    <message>
        <source>Automatically start Gridcoin after logging in to the system.</source>
        <translation>Démarrage automatique du client Gridcoin lors de la connexion au système</translation>
    </message>
    <message>
        <source>&amp;Start Gridcoin on system login</source>
        <translation>&amp;Démarrage du client Gridcoin à la connexion au système</translation>
    </message>
    <message>
        <source>Automatically open the Gridcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Ouverture automatique du port client de Gridcoin sur le routeur. Ceci ne fonctionne que dans le cas où le support UPnP sur votre routeur existe et est actif.</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. 127.0.0.1)</source>
        <translation>Addresse IP du proxy (e.g. 127.0.0.1)</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Port :</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Port du serveur mandataire (par ex. 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Minimiser au lieu de quitter l'application lorsque la fenêtre est fermée. Si cette option est activée, l'application ne pourra être fermée qu'en sélectionnant Quitter dans le menu.</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting Gridcoin.</source>
        <translation>La langue d'interface de de l'utilisateur peut être définie ici. Ces modification seront effectives après redémarrage de l'application Gridcoin</translation>
    </message>
    <message>
        <source>Whether to show Gridcoin addresses in the transaction list or not.</source>
        <translation>Afficher les adresses Gridcoin au sein de la liste de transactions</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Afficher les adresses sur la liste des transactions</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fenêtre</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation>&amp;Exécuter</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Afficher uniquement une icône système après minimisation.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimiser dans la barre système au lieu de la barre des tâches</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimiser lors de la fermeture</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Affichage</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Langue de l'interface utilisateur :</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Unité d'affichage des montants :</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Choisissez la sous-unité par défaut pour l'affichage dans l'interface et lors de l'envoi de pièces.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>default</source>
        <translation>par défaut</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <source>This setting will take effect after restarting Gridcoin.</source>
        <translation>Les paramètres prendront effet après redémarrage du client Gridcoin</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>L'adresse de serveur mandataire -proxy- fournie est invalide.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Votre solde actuel pouvant être dépensé</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Gridcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>Les informations affichées peuvent être obsolètes. Votre portefeuille se synchronise automatiquement avec le réseau Gridcoin mais ce processus n'est pas encore terminé.</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the current balance</source>
        <translation>Montant total des transactions nécessitant confirmation, et ne figurant pas encore dans la balance actuelle</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Votre solde total actuel</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>QRCodeDialog</name>
    <message>
        <source>QR Code Dialog</source>
        <translation>Boîte de dialogue QR Code</translation>
    </message>
    <message>
        <source>Request Payment</source>
        <translation>Demander un paiement</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Intitulé:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Montant :</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Enregistrer sous...</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Erreur d'encodage de l'URI en code QR.</translation>
    </message>
    <message>
        <source>The entered amount is invalid, please check.</source>
        <translation>Le montant indiqué est invalide, veuillez vérifier.</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>L'URI résultant est trop long, essayez de réduire le texte d'étiquette / de message.</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>Sauvegarder le QR Code</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>N.D.</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Version du client</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informations</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Heure de démarrage</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Nombre de connexions</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Chaîne de blocks</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Nombre actuel de blocks</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Horodatage du dernier block</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Ouvrir</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Journal de débogage</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Nettoyer la console</translation>
    </message>
    <message>
        <source>On testnet</source>
        <translation>Sur testnet</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Nombre total estimé de blocks</translation>
    </message>
    <message>
        <source>Open the Gridcoin debug log file from the current data directory. This can take a few seconds for large log files.</source>
        <translation>Ouvrir le fichier journal de debug Gridcoin au sein du répertoire courant. Cette opération peut prendre quelques secondes dans le cas de fichiers journaux volumineux.</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Options de ligne de commande</translation>
    </message>
    <message>
        <source>&amp;Show</source>
        <translation>&amp;Afficher</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Nom du client</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Utiliser les touches de curseur pour naviguer dans l'historique et &lt;b&gt;Ctrl-L&lt;/b&gt; pour effacer l'écran.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Taper &lt;b&gt;help&lt;/b&gt; pour afficher une vue générale des commandes disponibles.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Envoyer des monnaies</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Entrants...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>choisi automatiquement</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Fonds insuffisants !</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Quantité :</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Octets :</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Montant :</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Frais :</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Sortie faible</translation>
    </message>
    <message>
        <source>no</source>
        <translation>non</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Après les frais :</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Monnaie :</translation>
    </message>
    <message>
        <source>custom change address</source>
        <translation>adresse de change personnalisée</translation>
    </message>
    <message>
        <source>Remove all transaction fields</source>
        <translation>Réinitialiser tous les champs liés à la transaction</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Envoyer à plusieurs destinataires à la fois</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Ajouter un &amp;destinataire</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Tout nettoyer</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Confirmer l’action d'envoi</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>E&amp;nvoyer</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copier la quantité</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copier le montant</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copier les frais</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copier le montant après les frais</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copier les octets</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Copier la sortie faible</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copier la monnaie</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Confirmer l’envoi des pièces</translation>
    </message>
    <message>
        <source>Are you sure you want to send %1?</source>
        <translation>Etes-vous sûr de vouloir envoyer %1?</translation>
    </message>
    <message>
        <source> and </source>
        <translation>et</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>L'adresse du destinataire n’est pas valide, veuillez la vérifier.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Le montant à payer doit être supérieur à 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Le montant dépasse votre solde.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Le montant dépasse votre solde lorsque les frais de transaction de %1 sont inclus.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Adresse indentique trouvée, il n'est possible d'envoyer qu'une fois à chaque adresse par opération d'envoi.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed.</source>
        <translation>Erreur: Echec lors de la création de la transaction</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected. This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Erreur: La transaction a été rejetée. Cela peut se produire si une quantité d'argent de votre portefeuille a déjà été dépensée, comme dans le cas où une copie du fichier wallet.dat aurait été utilisée afin d'effectuer des dépenses, à la place du fichier courant.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(pas d'étiquette)</translation>
    </message>
    <message>
        <source>WARNING: Invalid Gridcoin address</source>
        <translation>AVERTISSEMENT: Adresse Gridcoin Invalide</translation>
    </message>
    <message>
        <source>WARNING: unknown change address</source>
        <translation>AVERTISSEMET: Adresse Gridcoin Invalide</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Montant :</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>&amp;Payer à :</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Étiquette :</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Coller l'adresse depuis le presse-papier</translation>
    </message>
    <message>
        <source>Choose address from address book</source>
        <translation>Choisir une adresse du carnet d'adresse</translation>
    </message>
    <message>
        <source>Remove this recipient</source>
        <translation>Supprimer ce destinataire</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Saisir une étiquette pour cette adresse afin de l’ajouter à votre carnet d’adresses</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Signatures - Signer / Vérifier un message</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Signer un message</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Vous pouvez signer des messages avec vos adresses pour prouver que vous les détenez. Faites attention de ne rien signer de suspect car des attaques d'hameçonnage peuvent essayer d'usurper votre identité par votre signature. Ne signez que des déclarations entièrement détaillées et avec lesquelles vous serez d'accord.</translation>
    </message>
    <message>
        <source>Choose an address from the address book</source>
        <translation>Choisir une adresse du carnet d'adresse</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Coller une adresse depuis le presse-papier</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Saisir ici le message que vous désirez signer</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Copier la signature actuelle dans le presse-papier</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Gridcoin address</source>
        <translation>Signer le message afin de prouver l'identité de votre adresse Gridcoin</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Réinitialiser tous les champs de signature de message</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Tout nettoyer</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Vérifier un message</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Saisir ci-dessous l'adresse de signature, le message (assurez-vous d'avoir copié exactement les retours à la ligne, les espaces, tabulations etc...) et la signature pour vérifier le message. Faire attention à ne pas déduire davantage de la signature que ce qui est contenu dans le message signé lui-même pour éviter d'être trompé par une attaque d'homme du milieu.</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Gridcoin address</source>
        <translation>Vérifier un message pour s'assurer qu'il vient d'un adresse Gridcoin spécifique.</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Réinitialiser tous les champs de vérification de message</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Cliquez sur « Signer le message » pour générer la signature</translation>
    </message>
    <message>
        <source>Enter Gridcoin signature</source>
        <translation>Entrer une signature Gridcoin</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>L'adresse saisie est invalide.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Veuillez vérifier l'adresse et réessayer.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>L'adresse saisie ne fait pas référence à une clef.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Le déverrouillage du portefeuille a été annulé.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>La clef privée pour l'adresse indiquée n'est pas disponible.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>La signature du message a échoué.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Le message a été signé.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>La signature n'a pu être décodée.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Veuillez vérifier la signature et réessayer.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>La signature ne correspond pas à l'empreinte du message.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Échec de la vérification du message.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Message vérifié.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Ouvert jusqu'à %1</translation>
    </message>
    <message>
        <source>conflicted</source>
        <translation>en conflit</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1/hors ligne</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/non confirmée</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>État</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, n’a pas encore été diffusée avec succès</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>From</source>
        <translation>De</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>inconnu</translation>
    </message>
    <message>
        <source>To</source>
        <translation>À</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>votre propre adresse</translation>
    </message>
    <message>
        <source>label</source>
        <translation>étiquette</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Crédit</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>refusé</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Débit</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Frais de transaction</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Montant net</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Commentaire</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Montant</translation>
    </message>
    <message>
        <source>true</source>
        <translation>vrai</translation>
    </message>
    <message>
        <source>false</source>
        <translation>faux</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Détails de la transaction</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Ce panneau affiche une description détaillée de la transaction</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Montant</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Ouvert jusqu'à %1</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Hors ligne</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Non confirmé</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Confirmée (%1 confirmations)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>En conflit</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Généré mais pas accepté</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Reçue avec</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Reçue de</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Envoyée à</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Paiement à vous-même</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(n.d)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>État de la transaction. Laissez le pointeur de la souris sur ce champ pour voir le nombre de confirmations.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Date et heure de réception de la transaction.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Type de transaction.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>L’adresse de destination de la transaction.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Montant ajouté ou enlevé au solde.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Aujourd’hui</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Cette semaine</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Ce mois-ci</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Le mois dernier</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Cette année</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Intervalle…</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Reçue avec</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Envoyée à</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>À vous-même</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Extrait</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Autres</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Montant min.</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copier l’adresse</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copier l’étiquette</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copier le montant</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copier l'ID de la transaction</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Modifier l’étiquette</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Afficher les détails de la transaction</translation>
    </message>
    <message>
        <source>Export Transaction Data</source>
        <translation>Exporter les données de la transaction</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmée</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Étiquette</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Montant</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Erreur lors de l'export</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Impossible d'écrire dans le fichier %1</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Intervalle :</translation>
    </message>
    <message>
        <source>to</source>
        <translation>à</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Sending...</source>
        <translation>Envoi...</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>Une erreur est survenue lors du réglage du port RPC %u pour écouter sur IPv6, retour à IPv4 : %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>Une erreur est survenue lors du réglage du port RPC %u pour écouter sur IPv4 : %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Utilisation :</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Lister les commandes</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Obtenir de l’aide pour une commande</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Attention : -paytxfee est réglée sur un montant très élevé ! Il s'agit des frais de transaction que vous payerez si vous envoyez une transaction.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Avertissement : wallet.dat corrompu, données récupérées ! Le fichier wallet.dat original a été enregistré en tant que wallet.{timestamp}.bak dans %s ; si votre solde ou transactions sont incorrects vous devriez effectuer une restauration depuis une sauvegarde.</translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Avertissement : une erreur est survenue lors de la lecture de wallet.dat ! Toutes les clefs ont été lues correctement mais les données de transaction ou les entrées du carnet d'adresses sont peut-être incorrectes ou manquantes.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed  </source>
        <translation>Erreur: La création de cette transaction à échouée</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected.  This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Erreur: La transaction a été rejetée. Cela peut se produire si une quantité d'argent de votre portefeuille a déjà été dépensée, comme dans le cas où une copie du fichier wallet.dat aurait été utilisée afin d'effectuer des dépenses, à la place du fichier courant.</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Échec de l'écoute sur un port quelconque. Utilisez -listen=0 si vous voulez ceci.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>Pour utiliser l'option %s</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Vous devez ajouter la ligne rpcpassword=&lt;mot-de-passe&gt; au fichier de configuration :
%s
Si le fichier n'existe pas, créez-le avec les droits de lecture seule accordés au propriétaire.</translation>
    </message>
    <message>
        <source>Gridcoin version</source>
        <translation>Version Gridcoin</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Montant invalide pour -paytxfee=&lt;montant&gt; : « %s »</translation>
    </message>
    <message>
        <source>Invalid amount for -mininput=&lt;amount&gt;: '%s'</source>
        <translation>Montant invalide pour -mininput=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Wallet %s resides outside data directory %s.</source>
        <translation>Le portefeuille %s réside en dehors répertoire de données %s</translation>
    </message>
    <message>
        <source>Verifying database integrity...</source>
        <translation>Vérification d'intégrité de la base de données...</translation>
    </message>
    <message>
        <source>Error initializing database environment %s! To recover, BACKUP THAT DIRECTORY, then remove everything from it except for wallet.dat.</source>
        <translation>Erreur lors de l'initialisation de l'environnement de base de données %s! Afin de procéder à la récupération, une SAUVEGARDE DE CE REPERTOIRE est nécessaire, puis, supprimez le contenu entier de ce répertoire, à l'exception du fichier wallet.dat </translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat corrompu, la récupération a échoué</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Adresse -proxy invalide : « %s »</translation>
    </message>
    <message>
        <source>Invalid -tor address: '%s'</source>
        <translation>Adresse -tor invalide: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>Impossible de résoudre l'adresse -bind : « %s »</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>Impossible de résoudre l'adresse -externalip : « %s »</translation>
    </message>
    <message>
        <source>Invalid amount for -reservebalance=&lt;amount&gt;</source>
        <translation>Montant incorrect pour -reservebalance=&lt;montant&gt;</translation>
    </message>
    <message>
        <source>Error loading blkindex.dat</source>
        <translation>Erreur de chargement du fichier blkindex.dat</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Erreur lors du chargement de wallet.dat : portefeuille corrompu</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet requires newer version of Gridcoin</source>
        <translation>Erreur de chargement du fichier wallet.dat: le portefeuille nécessite une version plus récente de l'application Gridcoin</translation>
    </message>
    <message>
        <source>Wallet needed to be rewritten: restart Gridcoin to complete</source>
        <translation>le portefeuille nécessite d'être réédité : Merci de relancer l'application Gridcoin</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Erreur lors du chargement de wallet.dat</translation>
    </message>
    <message>
        <source>Importing bootstrap blockchain data file.</source>
        <translation>Importation du fichier blockchain</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Chargement des adresses…</translation>
    </message>
    <message>
        <source>Error: could not start node</source>
        <translation>Erreur: Impossible de démarrer le noeud</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer. Gridcoin is probably already running.</source>
        <translation>Connexion au port %s impossible. L'application Gridcoin est probablement déjà en cours d'exécution</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Impossible de se lier à %s sur cet ordinateur (bind a retourné l'erreur %d, %s)</translation>
    </message>
    <message>
        <source>Error: Wallet locked, unable to create transaction  </source>
        <translation>Erreur: Portefeuille verrouillé, impossible d'effectuer cette transaction</translation>
    </message>
    <message>
        <source>Error: Wallet unlocked for staking only, unable to create transaction.</source>
        <translation>Erreur: Portefeuille déverrouillé uniquement pour "stacking" , impossible d'effectuer cette transaction</translation>
    </message>
    <message>
        <source>Error: This transaction requires a transaction fee of at least %s because of its amount, complexity, or use of recently received funds  </source>
        <translation>Erreur: Cette transaction requière des frais minimum de  %s a cause de son montant, de sa complexité ou de l'utilisation de fonds récemment reçus.</translation>
    </message>
    <message>
        <source>Sending...</source>
        <translation>Envoi...</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Montant invalide</translation>
    </message>
    <message>
        <source>Warning: Please check that your computer's date and time are correct! If your clock is wrong Gridcoin will not work properly.</source>
        <translation>Avertissement: Veuillez vérifier la date et l'heure de votre ordinateur. Gridcoin ne pourra pas fonctionner correctement si l'horloge est réglée de façon incorrecte</translation>
    </message>
    <message>
        <source>Warning: Disk space is low!</source>
        <translation>Avertissement: Espace disque faible!</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Réseau inconnu spécifié sur -onlynet : « %s »</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Fonds insuffisants</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Chargement de l’index des blocs…</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Chargement du portefeuille…</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Impossible d'écrire l'adresse par défaut</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Nouvelle analyse…</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Chargement terminé</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
</TS>